package com.recovery.auth.controller;


import cn.dev33.satoken.stp.SaTokenInfo;
import cn.dev33.satoken.stp.StpUtil;
import cn.dev33.satoken.util.SaResult;
import com.recovery.auth.exception.BusinessException;
import com.recovery.auth.feign.UserFeignClient;
import com.recovery.auth.security.details.user.JwtAuthenticationRequest;
import com.recovery.auth.service.AuthService;
import com.recovery.common.base.dto.UserAuthDTO;
import com.recovery.common.base.dto.UserAuthorityDto;
import com.recovery.common.base.result.ApiResult;
import com.recovery.common.base.result.ResultCode;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;

/**
 * @author： 
 */
@RestController
@RequestMapping("/oauth")
@AllArgsConstructor
@Slf4j
public class AuthController {

    @Resource
    AuthService authService;
    @Resource
    UserFeignClient userFeignClient;

    @PostMapping("/token")
    public ApiResult postAccessToken(@RequestBody JwtAuthenticationRequest authenticationRequest, HttpServletRequest request){
        log.info("----------------获取token");
        HashMap map= new HashMap();
        try {
            map = authService.login(authenticationRequest, request);
        }catch (Exception e){
            log.error("获取token："+e.getMessage(),e);
            return ApiResult.failed(e.getMessage());
        }
        return ApiResult.ok(map);
    }

    @GetMapping("/doLogin")
    public SaResult doLogin(@RequestBody JwtAuthenticationRequest authenticationRequest) {
        if(StringUtils.isEmpty(authenticationRequest.getUsername())){
            throw new BusinessException("账户不能为空");
        }
        if(StringUtils.isEmpty(authenticationRequest.getPassword())){
            throw new BusinessException("密码不能为空");
        }

        ApiResult<UserAuthDTO> result = userFeignClient.getUserByUsername(authenticationRequest.getUsername());
        UserAuthDTO userDetails = new UserAuthDTO();
        if (ResultCode.SUCCESS.getCode().equals(result.getCode())) {
            userDetails = result.getData();
        }
        // 此处仅作模拟示例，真实项目需要从数据库中查询数据进行比对
        if (userDetails.getUserName().equals(authenticationRequest.getUsername()) && userDetails.getPassword().equals(authenticationRequest.getPassword())) {
            log.info("密码校验成功！");
            StpUtil.login(userDetails.getUserName());
        }else {
            return SaResult.error("密码错误");
        }
        // 第3步，返回给前端
        SaTokenInfo tokenInfo = StpUtil.getTokenInfo();
        return SaResult.ok("登录成功").setData(tokenInfo);
    }

//    @GetMapping("/public-key")
//    public Map<String, Object> getPublicKey() {
//       //单例模式
//
//        return “吃啥;
//    }
}
